<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package STEVEN WATKINS
 * @since STEVEN WATKINS 1.0
 */

$steven_watkins_template = apply_filters( 'steven_watkins_filter_get_template_part', steven_watkins_blog_archive_get_template() );

if ( ! empty( $steven_watkins_template ) && 'index' != $steven_watkins_template ) {

	get_template_part( $steven_watkins_template );

} else {

	steven_watkins_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$steven_watkins_stickies   = is_home()
								|| ( in_array( steven_watkins_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) steven_watkins_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$steven_watkins_post_type  = steven_watkins_get_theme_option( 'post_type' );
		$steven_watkins_args       = array(
								'blog_style'     => steven_watkins_get_theme_option( 'blog_style' ),
								'post_type'      => $steven_watkins_post_type,
								'taxonomy'       => steven_watkins_get_post_type_taxonomy( $steven_watkins_post_type ),
								'parent_cat'     => steven_watkins_get_theme_option( 'parent_cat' ),
								'posts_per_page' => steven_watkins_get_theme_option( 'posts_per_page' ),
								'sticky'         => steven_watkins_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $steven_watkins_stickies )
															&& count( $steven_watkins_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		steven_watkins_blog_archive_start();

		do_action( 'steven_watkins_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'steven_watkins_action_before_page_author' );
			get_template_part( apply_filters( 'steven_watkins_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'steven_watkins_action_after_page_author' );
		}

		if ( steven_watkins_get_theme_option( 'show_filters' ) ) {
			do_action( 'steven_watkins_action_before_page_filters' );
			steven_watkins_show_filters( $steven_watkins_args );
			do_action( 'steven_watkins_action_after_page_filters' );
		} else {
			do_action( 'steven_watkins_action_before_page_posts' );
			steven_watkins_show_posts( array_merge( $steven_watkins_args, array( 'cat' => $steven_watkins_args['parent_cat'] ) ) );
			do_action( 'steven_watkins_action_after_page_posts' );
		}

		do_action( 'steven_watkins_action_blog_archive_end' );

		steven_watkins_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'steven_watkins_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'steven_watkins_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
