<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package STEVEN WATKINS
 * @since STEVEN WATKINS 1.0
 */

if ( steven_watkins_sidebar_present() ) {
	
	$steven_watkins_sidebar_type = steven_watkins_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $steven_watkins_sidebar_type && ! steven_watkins_is_layouts_available() ) {
		$steven_watkins_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $steven_watkins_sidebar_type ) {
		// Default sidebar with widgets
		$steven_watkins_sidebar_name = steven_watkins_get_theme_option( 'sidebar_widgets' );
		steven_watkins_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $steven_watkins_sidebar_name ) ) {
			dynamic_sidebar( $steven_watkins_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$steven_watkins_sidebar_id = steven_watkins_get_custom_sidebar_id();
		do_action( 'steven_watkins_action_show_layout', $steven_watkins_sidebar_id );
	}
	$steven_watkins_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $steven_watkins_out ) ) {
		$steven_watkins_sidebar_position    = steven_watkins_get_theme_option( 'sidebar_position' );
		$steven_watkins_sidebar_position_ss = steven_watkins_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $steven_watkins_sidebar_position );
			echo ' sidebar_' . esc_attr( $steven_watkins_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $steven_watkins_sidebar_type );

			$steven_watkins_sidebar_scheme = apply_filters( 'steven_watkins_filter_sidebar_scheme', steven_watkins_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $steven_watkins_sidebar_scheme ) && ! steven_watkins_is_inherit( $steven_watkins_sidebar_scheme ) && 'custom' != $steven_watkins_sidebar_type ) {
				echo ' scheme_' . esc_attr( $steven_watkins_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="steven_watkins_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'steven_watkins_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $steven_watkins_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$steven_watkins_title = apply_filters( 'steven_watkins_filter_sidebar_control_title', 'float' == $steven_watkins_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'steven-watkins' ) : '' );
				$steven_watkins_text  = apply_filters( 'steven_watkins_filter_sidebar_control_text', 'above' == $steven_watkins_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'steven-watkins' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $steven_watkins_title ); ?>"><?php echo esc_html( $steven_watkins_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'steven_watkins_action_before_sidebar', 'sidebar' );
				steven_watkins_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $steven_watkins_out ) );
				do_action( 'steven_watkins_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'steven_watkins_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
